@@ -11,9 +11,10 @@ use lib qw(../lib);
 {
 	package Reflex::UdpPeer::Echo;
 	use Moose;
+	extends 'Reflex::Object';
 	with 'Reflex::Role::UdpPeer';
 
-	sub on_my_datagram {
+	sub on_udppeer_datagram {
 		my ($self, $args) = @_;
 		my $data = $args->{datagram};
 
@@ -28,7 +29,7 @@ use lib qw(../lib);
 		);
 	}
 
-	sub on_my_error {
+	sub on_udppeer_error {
 		my ($self, $args) = @_;
 		warn "$args->{op} error $args->{errnum}: $args->{errstr}";
 		$self->destruct();
