@@ -53,5 +53,5 @@ my $promise;
 my $pt = PromiseThing->new( cb_promise(\$promise) );
 
 while (my $event = $promise->wait()) {
-	eg_say("wait() returned an event (@$event)");
+	eg_say("wait() returned an event ($event->{name})");
 }
